<?php
/**
 *Guideline Theme Customizer
 *
 * @package Guideline
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function guideline_customize_register( $wp_customize ) {
	
	//Add a class for titles
    class guideline_Info extends WP_Customize_Control {
        public $type = 'info';
        public $label = '';
        public function render_content() {
        ?>
			<h4><?php echo esc_html( $this->label ); ?></h4>
        <?php
        }
    }
	
	function guideline_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}
	
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';	
	
	//Site Layout Section
	$wp_customize->add_section('site_layout_sec',array(
			'title'	=> __('Site Layout','guideline'),			
			'priority'	=> 1,
	));		
	
	$wp_customize->add_setting('box_layout',array(
			'sanitize_callback' => 'guideline_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'box_layout', array(
    	   'section'   => 'site_layout_sec',    	 
		   'label'	=> __('Check to Box Layout','guideline'),
    	   'type'      => 'checkbox'
     )); //Site Layout Section 
	 
	 
	 //Site Sticky Header
	$wp_customize->add_section('sticky_header_sec',array(
			'title'	=> __('Sticky Header','guideline'),			
			'priority'	=> 1,
	));		
	
	$wp_customize->add_setting('stickyheader',array(
			'default' => true,
			'sanitize_callback' => 'guideline_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'stickyheader', array(
    	   'section'   => 'sticky_header_sec',    	 
		   'label'	=> __('Check to disable sticky header','guideline'),
    	   'type'      => 'checkbox'
     )); //Site Layout Section 
	
	
	$wp_customize->add_setting('color_scheme',array(
			'default'	=> '#f98700',
			'sanitize_callback'	=> 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'color_scheme',array(
			'label' => __('Color Scheme','guideline'),			
			 'description'	=> __('More color options in PRO Version','guideline'),
			'section' => 'colors',
			'settings' => 'color_scheme'
		))
	);
	
	
	// Slider Section		
	$wp_customize->add_section( 'header_slider', array(
            'title' => __('Header Slider', 'guideline'),
            'priority' => null,
            'description'	=> __('Reccomded Featured Image Size( 1400x600 )','guideline'),		
     ));	
	
	$wp_customize->add_setting('slider-page5',array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));
	
	$wp_customize->add_control('slider-page5',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide one:','guideline'),
			'section'	=> 'header_slider'
	));	
	
	$wp_customize->add_setting('slider-page6',array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));
	
	$wp_customize->add_control('slider-page6',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide two:','guideline'),
			'section'	=> 'header_slider'
	));	
	
	$wp_customize->add_setting('slider-page7',array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));
	
	$wp_customize->add_control('slider-page7',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide three:','guideline'),
			'section'	=> 'header_slider'
	));	// Slider Section	
	
	
	$wp_customize->add_setting('hide_slider',array(
				'default' => true,
				'sanitize_callback' => 'guideline_sanitize_checkbox',
				'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'hide_slider', array(
			   'settings' => 'hide_slider',
			   'section'   => 'header_slider',
			   'label'     => __('Uncheck To Enable This Section','guideline'),
			   'type'      => 'checkbox'
	 ));//Disable Slider Section
	 
	 
	// Four Services Boxes Section 	
	$wp_customize->add_section('section_second', array(
		'title'	=> __('Services Section','guideline'),
		'description'	=> __('Select Pages from the dropdown for services section','guideline'),
		'priority'	=> null
	));	
	
	$wp_customize->add_setting('page-column1',	array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
		));
 
	$wp_customize->add_control(	'page-column1',array('type' => 'dropdown-pages',			
			'section' => 'section_second',
	));		
	
	$wp_customize->add_setting('page-column2',	array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
		));
 
	$wp_customize->add_control(	'page-column2',array('type' => 'dropdown-pages',			
			'section' => 'section_second',
	));
	
	$wp_customize->add_setting('page-column3',	array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
		));
 
	$wp_customize->add_control(	'page-column3',array('type' => 'dropdown-pages',			
			'section' => 'section_second',
	));
	
	$wp_customize->add_setting('page-column4',	array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
		));
 
	$wp_customize->add_control(	'page-column4',array('type' => 'dropdown-pages',			
			'section' => 'section_second',
	));//end four column page boxes	
	
	$wp_customize->add_setting('disabled_pgboxes',array(
			'default' => true,
			'sanitize_callback' => 'guideline_sanitize_checkbox',
			'capability' => 'edit_theme_options',
	));	 
	
	$wp_customize->add_control( 'disabled_pgboxes', array(
			   'settings' => 'disabled_pgboxes',
			   'section'   => 'section_second',
			   'label'     => __('Uncheck To Enable This Section','guideline'),
			   'type'      => 'checkbox'
	 ));//Disable services Section	
}
add_action( 'customize_register', 'guideline_customize_register' );

function guideline_custom_css(){
		?>
        	<style type="text/css"> 					
					a, .blog_lists h2 a:hover,
					#sidebar ul li a:hover,									
					.blog_lists h3 a:hover,
					.ftr-4-box ul li a:hover, .ftr-4-box ul li.current_page_item a,
					.recent-post h6:hover,					
					.colsfour:hover h3,
					.footer-icons a:hover,
					.sitenav ul li a:hover, .sitenav ul li.current_page_item a, 
					.postmeta a:hover
					{ color:<?php echo esc_html( get_theme_mod('color_scheme','#f98700')); ?>;}
					 
					
					.pagination ul li .current, .pagination ul li a:hover, 
					#commentform input#submit:hover,					
					.nivo-controlNav a.active,
					.ReadMore:hover,
					.appbutton:hover,					
					.slide_info .slide_more,			
					.sitenav ul li.current-menu-ancestor a.parent,					
					#sidebar .search-form input.search-submit,				
					.wpcf7 input[type='submit']					
					{ background-color:<?php echo esc_html( get_theme_mod('color_scheme','#f98700')); ?>;}
					
					
					.footer-icons a:hover							
					{ border-color:<?php echo esc_html( get_theme_mod('color_scheme','#f98700')); ?>;}					
					
			</style> 
<?php                          
}         
add_action('wp_head','guideline_custom_css');


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function guideline_customize_preview_js() {
	wp_enqueue_script( 'guideline_customizer', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '20161125', true );
}
add_action( 'customize_preview_init', 'guideline_customize_preview_js' );